@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -28,8 +27,7 @@ extensions = [
 
 # openstackdocstheme options
 repository_name = 'openstack/python-vitrageclient'
-bug_project = 'python-vitrageclient'
-bug_tag = ''
+use_storyboard = True
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
